#ifndef STRUCT_COPIED_DATA_H
#define STRUCT_COPIED_DATA_H

#include <sys/types.h>

typedef struct copied_data
{
	off_t file_count;
	off_t dir_count;
	off_t link_count;
	off_t mk_file_count;
	off_t mk_dir_count;
	off_t mk_link_count;
	off_t total_source;
	off_t total_read;
	off_t total_write;
	off_t total_error;
} CPDD;

#endif
